# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.8.0~5b6fa3e',
    built_at='2024-07-02 08:04:25Z',
    sha='5b6fa3e7726cd90c300fa2acb89b719b2877c01e',
    branch='HEAD',
    tag='v4.8.0',
)
